package com.lemon.lifecenter.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.lemon.lifecenter.dto.CenterInfoDTO;
import com.lemon.lifecenter.dto.StaffDTO;
import com.lemon.lifecenter.mapper.StaffMapper;

@Service
public class StaffService {
    @Autowired
    private StaffMapper mapper;
    
    public int selectMemberCount(StaffDTO dto) {
        return mapper.selectMemberCount(dto);
    }
    
    public int selectMemeberListCount(StaffDTO dto) {
        return mapper.selectMemberListCount(dto);
    }
    
    public List<StaffDTO> selectMemberList(StaffDTO dto) {
        return mapper.selectMemberList(dto);
    }
    
    public void inserMember(StaffDTO dto) {
        mapper.insertMember(dto);
    }
    
    public Integer updateMember(StaffDTO dto) {
        return mapper.updateMember(dto);
    }
    
    public StaffDTO selectMemberInfo(StaffDTO dto) {
        return mapper.selectMemberInfo(dto);
    }
    
    public List<CenterInfoDTO> selectCenterList() {
        return mapper.selectCenterList();
    }
    
    public void insertStaff(StaffDTO dto) {
        mapper.insertStaff(dto);
    }
}
